% Solve 1-D Rosenau equation on [-L,L] with RBF
% collocation method with fictitious points
% and plot the exact and numerical solution at given time set
%
% Equation
% u_t + 0.5*u_xxxxt = g(u)_x
% 
% with boundary conditions
% u(-L,t) = sech(-L-t)
% u(+L,t) = sech(+L-t)
% u_x(-L,t) = sech(t+L)tanh(t+L)
% u_x(+L,t) = sech(t-L)tanh(t-L)
%
% Initial condition: u(x,t) = sech(x-t)
%
% g(u) = 10u^3 - 12u^5 - 3u/2
% g(u)_x = (-3/2)u_x - 60u^4u_x + 30u^2u_x
%
% Copyright (C) 2015 Ali Safdari, Elisabeth Larsson and Alfa Heryudono
% This MATLAB code is released to support reproducible research for numerical 
% results in the manuscript:
% Radial basis function methods for the Rosenau equation and
% other higher order PDEs
% Status: Submitted
% Ali Safdari-Vaighani, Elisabeth Larsson, Alfa Heryudono.

function FP_RBF_Nsolution(N,L,Tset)
% N : The number of node points
% L : [-L,L] is the domain
% Tset : Set of time

% Sample set of time
% Tset = [0.1 3 6]; 
% Tset = [0.1 .5 1]; 

u = @(x,t) sech(x-t); % Exact solution

for k = 1:length(Tset)
[S,x,t] = FP_RBF(N,L,Tset(k));
% E(k)= max(abs(S(end,:)-u(x(3:N-2),T)'))
figure(2);
plot(x(3:N-2),u(x(3:N-2),Tset(k))','-r','LineWidth',2); hold on
plot(x(3:N-2),S(end,:)','ko','markersize',3,'markerfacecolor','k');
set(gca,'Fontsize',15);
xlabel('x'); ylabel('u(x,t)'); xlim([-L L]); ylim([0 1.2])
legend('exact','numerical','Location','NorthWest');
text(-.2+Tset(k),1.05,['t = ' ,num2str(Tset(k))],'FontSize',12)
hold on

end


