% Error as function of N for 1-D Rosenau equation on [-L,L] with RBF
% collocation method with FP-RBF and RS-RBF methods
%
% Equation
% u_t + 0.5*u_xxxxt = g(u)_x
% 
% with boundary conditions
% u(-L,t) = sech(-L-t)
% u(+L,t) = sech(+L-t)
% u_x(-L,t) = sech(t+L)tanh(t+L)
% u_x(+L,t) = sech(t-L)tanh(t-L)
%
% Initial condition: u(x,t) = sech(x-t)
%
% g(u) = 10u^3 - 12u^5 - 3u/2
% g(u)_x = (-3/2)u_x - 60u^4u_x + 30u^2u_x
%
% Copyright (C) 2015 Ali Safdari, Elisabeth Larsson and Alfa Heryudono
% This MATLAB code is released to support reproducible research for numerical 
% results in the manuscript:
% Radial basis function methods for the Rosenau equation and
% other higher order PDEs
% Status: Submitted
% Ali Safdari-Vaighani, Elisabeth Larsson, Alfa Heryudono.

function RBF_Error(Nset,L,T,ep)
% Nset : The set of node points
% L : [-L,L] is the domain
% T : Final time
% ep : Shape parameter

% Sample of the set of node points
% Nset = [6 10 14 18 22 26 30]
% Nset = [30 40 50 60 70 80 90 100]

u = @(x,t) sech(x-t); % Exact solution

for k = 1:length(Nset)
    N = Nset(k);
    [Sf,xf,tf] = FP_RBF(N,L,T,ep);
    Ef(k)= max(abs(Sf(end,:)-u(xf(3:N-2),T)'))
    [Sr,xr,tr] = RS_RBF(N,L,T,ep);
    Er(k)= max(abs(Sr(end,:)-u(xr,T)'))
end

figure(3);
semilogy(Nset,Ef,'ok--','LineWidth',2,'Markersize',10);hold on
semilogy(Nset,Er,'bd-','LineWidth',2,'Markersize',10)
set(gca,'Fontsize',15); hold on; grid on;
xlabel('N'); ylabel('||E(1)||_\infty'); ylim([1e-6 .5]); 
xlim([Nset(1) Nset(end)]);
set(gca,'ytick',10.^(-6:0))
set(gca,'YMinorGrid','off')





